==> create-mashup-app-2.0.2.tgz: package/cli.js <==
#!/usr/bin/env node

const generateApp = require('./src/commands/generateApp');
const devServer = require('./src/commands/devServer');
const buildApp = require('./src/commands/buildApp');
const program = require('commander');
const {version} = require('./package.json');

program.version(version);

program
  .command('generate')
  .description(
    'generate new mashup client integration app at current directory'
  )
  .action(generateApp);

program
  .command('build [dir]')
  .description(
    'build existing mashup client integration app at current directory'
  )
  .option('--no-minify', 'disable output bundle minification')
  .option(
    '--no-dependency-replace',
    'disable mashup dependency replacement in output bundle'
  )
  .option('--mashup', 'output target is a mashup, not an integration module')
  .option('-o, --outputDir [outputDir]', 'Output directory', './dist')
  .action(buildApp);

program
  .command('devServer [dir]')
  .description(
    'run dev server for mashup client integration app at current directory'
  )
  .option('--minify', 'force output bundle minification')
  .option(
    '--no-dependency-replace',
    'disable mashup dependency replacement in output bundle'
  )
  .option('--port [number]', 'dev server listener port')
  .option(
    '--mashup',
    'output target is a mashup and should work in watch mode instead of devServer'
  )
  .option('-o', '--outputDir [outputDir]', 'Output directory', './dist')
  .action(devServer);

program.parse(process.argv);

if (program.args.length === 0) {
  program.help();
}

==> create-mashup-app-2.4.0.tgz: package/cli.js <==
#!/usr/bin/env node

const generateApp = require('./src/commands/generateApp');
const devServer = require('./src/commands/devServer');
const buildApp = require('./src/commands/buildApp');
const program = require('commander');
const {version} = require('./package.json');

program.version(version);

program
  .command('generate')
  .description(
    'generate new mashup client integration app at current directory'
  )
  .action(generateApp);

program
  .command('build [dir]')
  .description(
    'build existing mashup client integration app at current directory'
  )
  .option('--no-minify', 'disable output bundle minification')
  .option(
    '--no-dependency-replace',
    'disable mashup dependency replacement in output bundle'
  )
  .option('--mashup', 'output target is a mashup, not an integration module')
  .option('--outputDir [outputDir]', 'Output directory', './dist')
  .action(buildApp);

program
  .command('devServer [dir]')
  .description(
    'run dev server for mashup client integration app at current directory'
  )
  .option('--minify', 'force output bundle minification')
  .option(
    '--no-dependency-replace',
    'disable mashup dependency replacement in output bundle'
  )
  .option('--port [number]', 'dev server listener port')
  .option(
    '--mashup',
    'output target is a mashup and should work in watch mode instead of devServer'
  )
  .option('--outputDir [outputDir]', 'Output directory', './dist')
  .action(devServer);

program.parse(process.argv);

if (program.args.length === 0) {
  program.help();
}
